| Title: | An Interface to the Naruto Database API |
|---|---|
| Description: | The NarutoDB API <https://narutodb.xyz> offers a comprehensive database featuring all the characters, clans, villages, kekkei genkai, tailed beasts, teams, akatsuki, and rara members from the renowned anime and manga series *Naruto*. The API provides detailed information on each character, including their names, appearances, personalities, jutsus, and ninja tools. This package interfaces with the NarutoDB API through R. |
| Authors: | Ernest Guevarra [aut, cre] (ORCID: <https://orcid.org/0000-0002-4887-4415>) |
| Maintainer: | Ernest Guevarra <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-28 07:54:27 UTC |
| Source: | https://github.com/OxfordIHTM/naruto |
Get all Naruto characters available from NarutoDB
naruto_get_characters( base_url = "https://narutodb.xyz", json = FALSE, clean_names = TRUE ) naruto_get_character_by_id(id, base_url = "https://narutodb.xyz")naruto_get_characters( base_url = "https://narutodb.xyz", json = FALSE, clean_names = TRUE ) naruto_get_character_by_id(id, base_url = "https://narutodb.xyz")
base_url |
Base URL of the NarutoDB API. This is currently set to "https://narutodb.xyz". |
json |
Logical. Should output be returned as JSON? If FALSE (default), returns a data.frame. Otherwise, returns a standard JSON format output. |
clean_names |
Logical. Should data.frame output variable names be
cleaned? If TRUE (default), variable names are tidied appropriately.
Otherwise, variable names are kept as is. Only evaluated when
|
id |
A numeric value or vector of numeric values for the unique identifier of Naruto characters. |
If json = TRUE, returns a simplified and flattend data.frame. If
json = FALSE, returns a standard JSON format output. See
https://narutodb.xyz/docs/characters/characterSchema for schema of
NarutoDB characters output.
naruto_get_characters() naruto_get_character_by_id(id = 55)naruto_get_characters() naruto_get_character_by_id(id = 55)